@@ -61,7 +61,6 @@ MainWindow::MainWindow():
   QMainWindow(),
   contextMenu_(new QMenu(this)),
   slideShowTimer_(nullptr),
-  image_(),
   // currentFileInfo_(nullptr),
   imageModified_(false),
   folder_(nullptr),
@@ -110,9 +109,8 @@ MainWindow::MainWindow():
   // install an event filter on the image view
   ui.view->installEventFilter(this);
 
-  ui.view->setBackgroundBrush(QBrush(settings.bgColor()));
-
-  ui.view->updateOutline();
+  ui.view->setViewBackground(QBrush(settings.bgColor()), settings.solidBg());
+  ui.actionSolidBg->setChecked(settings.solidBg());
 
   ui.view->showOutline(settings.isOutlineShown());
   ui.actionShowOutline->setChecked(settings.isOutlineShown());
@@ -160,6 +158,11 @@ MainWindow::MainWindow():
   ui.actionOriginalSize->setActionGroup(aGroup);
   ui.actionZoomFit->setChecked(true);
 
+  ui.actionNextFrame->setVisible(false);
+  ui.actionPreviousFrame->setVisible(false);
+  ui.actionFirstFrame->setVisible(false);
+  ui.actionLastFrame->setVisible(false);
+
   contextMenu_->addAction(ui.actionPrevious);
   contextMenu_->addAction(ui.actionNext);
   contextMenu_->addSeparator();
@@ -170,6 +173,7 @@ MainWindow::MainWindow():
   contextMenu_->addSeparator();
   contextMenu_->addAction(ui.actionSlideShow);
   contextMenu_->addAction(ui.actionFullScreen);
+  contextMenu_->addAction(ui.actionSolidBg);
   contextMenu_->addAction(ui.actionShowOutline);
   contextMenu_->addAction(ui.actionShowExifData);
   contextMenu_->addAction(ui.actionShowThumbnails);
@@ -500,8 +504,7 @@ void MainWindow::pasteImage(QImage newImage) {
   currentIndex_ = QModelIndex(); // invaludate current index since we don't have a folder model now
   currentFile_ = Fm::FilePath{};
 
-  image_ = newImage;
-  ui.view->setImage(image_);
+  ui.view->setImage(newImage);
   // always fit the image on pasting
   ui.actionZoomFit->setChecked(true);
   ui.view->setAutoZoomFit(true);
@@ -616,7 +619,7 @@ void MainWindow::on_actionSave_triggered() {
   if(saveJob_) // if we're currently saving another file
     return;
 
-  if(!image_.isNull()) {
+  if(!ui.view->image().isNull()) {
     if(currentFile_)
       saveImage(currentFile_);
     else
@@ -715,6 +718,30 @@ void MainWindow::on_actionLast_triggered() {
   }
 }
 
+void MainWindow::on_actionNextFrame_triggered() {
+  ui.view->nextFrame();
+  int frame = ui.view->currentFrame();
+  ui.statusBar->setPermanentText(frame > 0 ? tr("%1/%2 Frames").arg(frame).arg(ui.view->frameCount()) : QString());
+}
+
+void MainWindow::on_actionPreviousFrame_triggered() {
+  ui.view->previousFrame();
+  int frame = ui.view->currentFrame();
+  ui.statusBar->setPermanentText(frame > 0 ? tr("%1/%2 Frames").arg(frame).arg(ui.view->frameCount()) : QString());
+}
+
+void MainWindow::on_actionFirstFrame_triggered() {
+  ui.view->firstFrame();
+  int frame = ui.view->currentFrame();
+  ui.statusBar->setPermanentText(frame > 0 ? tr("%1/%2 Frames").arg(frame).arg(ui.view->frameCount()) : QString());
+}
+
+void MainWindow::on_actionLastFrame_triggered() {
+  ui.view->lastFrame();
+  int frame = ui.view->currentFrame();
+  ui.statusBar->setPermanentText(frame > 0 ? tr("%1/%2 Frames").arg(frame).arg(ui.view->frameCount()) : QString());
+}
+
 void MainWindow::loadFolder(const Fm::FilePath & newFolderPath) {
   if(folder_) { // an folder is already loaded
     if(newFolderPath == folderPath_) { // same folder, ignore
@@ -744,7 +771,7 @@ void MainWindow::onImageLoaded() {
     // Add to the MRU menu
     ui.menuRecently_Opened_Files->addItem(QString::fromUtf8(loadJob_->filePath().localPath().get()));
 
-    image_ = loadJob_->image();
+    QImage img = loadJob_->image();
     exifData_ = loadJob_->getExifData();
 
     loadJob_ = nullptr; // the job object will be freed later automatically
@@ -753,7 +780,7 @@ void MainWindow::onImageLoaded() {
 
     int cs = settings.colorSpace();
     if(cs > 0 && cs < 6) {
-      image_.convertToColorSpace(QColorSpace(static_cast<QColorSpace::NamedColorSpace>(cs)));
+      img.convertToColorSpace(QColorSpace(static_cast<QColorSpace::NamedColorSpace>(cs)));
     }
 
     // set image zoom, like in loadImage()
@@ -765,7 +792,7 @@ void MainWindow::onImageLoaded() {
       ui.view->zoomOriginal();
     }
 
-    ui.view->setImage(image_);
+    ui.view->setImage(img);
 
     // currentIndex_ should be corrected after loading
     currentIndex_ = indexFromPath(currentFile_);
@@ -847,7 +874,7 @@ QModelIndex MainWindow::indexFromPath(const Fm::FilePath & filePath) {
 }
 
 
-void MainWindow::updateUI() {
+void MainWindow::updateUI(bool multiFrame) {
   if(currentIndex_.isValid()) {
     if(thumbnailsView_) { // showing thumbnails
       // select current file in the thumbnails view
@@ -871,7 +898,7 @@ void MainWindow::updateUI() {
       ui.statusBar->setText();
     }
     else {
-      if(image_.isNull()) {
+      if(ui.view->image().isNull()) {
         title = tr("[*]%1 (Failed to Load) - Image Viewer")
                   .arg(QString::fromUtf8(dispName.get()));
         ui.statusBar->setText();
@@ -880,10 +907,15 @@ void MainWindow::updateUI() {
         const QString filePath = QString::fromUtf8(dispName.get());
         title = tr("[*]%1 (%2x%3) - Image Viewer")
                   .arg(filePath)
-                  .arg(image_.width())
-                  .arg(image_.height());
-        ui.statusBar->setText(QStringLiteral("%1×%2").arg(image_.width()).arg(image_.height()),
+                  .arg(ui.view->image().width())
+                  .arg(ui.view->image().height());
+        ui.statusBar->setText(QStringLiteral("%1×%2").arg(ui.view->image().width())
+                                                     .arg(ui.view->image().height()),
                               filePath);
+        int frame = ui.view->currentFrame();
+        ui.statusBar->setPermanentText(multiFrame && frame > 0
+                                       ? tr("%1/%2 Frames").arg(frame).arg(ui.view->frameCount())
+                                       : QString());
         if (!isVisible()) {
           /* Here we try to implement the following behavior as far as possible:
               (1) A minimum size of 600x400 is assumed;
@@ -899,7 +931,7 @@ void MainWindow::updateUI() {
           setAttribute(Qt::WA_DontShowOnScreen);
           show();
           int scrollThickness = style()->pixelMetric(QStyle::PM_ScrollBarExtent);
-          QSize newSize = size() + image_.size() - ui.view->size() + QSize(scrollThickness, scrollThickness);
+          QSize newSize = size() + ui.view->image().size() - ui.view->size() + QSize(scrollThickness, scrollThickness);
           bool isWayland(QGuiApplication::platformName() == QStringLiteral("wayland"));
           QScreen *appScreen = nullptr;
           if(isWayland) {
@@ -946,7 +978,13 @@ void MainWindow::updateUI() {
   }
   else {
     title = tr("[*]Image Viewer");
-    ui.statusBar->setText();
+    if(ui.view->image().isNull()) {
+      ui.statusBar->setText();
+    }
+    else {
+      ui.statusBar->setText(QStringLiteral("%1×%2").arg(ui.view->image().width())
+                                                   .arg(ui.view->image().height()));
+    }
   }
   setWindowTitle(title);
   setWindowModified(imageModified_);
@@ -968,8 +1006,6 @@ void MainWindow::loadImage(const Fm::FilePath & filePath, QModelIndex index) {
 
   currentIndex_ = index;
   currentFile_ = filePath;
-  // clear current image, but do not update the view now to prevent flickers
-  image_ = QImage();
 
   const Fm::CStrPtr basename = currentFile_.baseName();
   char* mime_type = g_content_type_guess(basename.get(), nullptr, 0, nullptr);
@@ -978,14 +1014,33 @@ void MainWindow::loadImage(const Fm::FilePath & filePath, QModelIndex index) {
     mimeType = QString::fromUtf8(mime_type);
     g_free(mime_type);
   }
-  if(mimeType == QLatin1String("image/gif")
-     || mimeType == QLatin1String("image/svg+xml") || mimeType == QLatin1String("image/svg+xml-compressed")) {
+
+  const Fm::CStrPtr file_name = currentFile_.toString();
+
+  ui.actionNextFrame->setVisible(false);
+  ui.actionPreviousFrame->setVisible(false);
+  ui.actionFirstFrame->setVisible(false);
+  ui.actionLastFrame->setVisible(false);
+  bool supportsAnimation(mimeType == QLatin1String("image/gif"));
+  if(!supportsAnimation
+     && (mimeType == QLatin1String("image/tiff") || mimeType == QLatin1String("image/webp"))) {
+    supportsAnimation = ui.view->supportsAnimation(QString::fromUtf8(file_name.get()));
+    if(supportsAnimation && mimeType == QLatin1String("image/tiff")) {
+      ui.actionNextFrame->setVisible(true);
+      ui.actionPreviousFrame->setVisible(true);
+      ui.actionFirstFrame->setVisible(true);
+      ui.actionLastFrame->setVisible(true);
+    }
+  }
+
+  if(supportsAnimation
+     || mimeType == QLatin1String("image/svg+xml")
+     || mimeType == QLatin1String("image/svg+xml-compressed")) {
     if(!currentIndex_.isValid()) {
       // since onImageLoaded is not called here,
       // currentIndex_ should be set
       currentIndex_ = indexFromPath(currentFile_);
     }
-    const Fm::CStrPtr file_name = currentFile_.toString();
 
     // set image zoom, like in onImageLoaded()
     Settings& settings = static_cast<Application*>(qApp)->settings();
@@ -997,12 +1052,14 @@ void MainWindow::loadImage(const Fm::FilePath & filePath, QModelIndex index) {
       ui.view->zoomOriginal();
     }
 
-    if(mimeType == QLatin1String("image/gif"))
-      ui.view->setGifAnimation(QString::fromUtf8(file_name.get()));
-    else
+    if(supportsAnimation) {
+      ui.view->setGifAnimation(QString::fromUtf8(file_name.get()),
+                               mimeType != QLatin1String("image/tiff"));
+    }
+    else {
       ui.view->setSVG(QString::fromUtf8(file_name.get()));
-    image_ = ui.view->image();
-    updateUI();
+    }
+    updateUI(supportsAnimation && mimeType == QLatin1String("image/tiff"));
     if(!isVisible()) {
       if(settings.windowMaximized()) {
         setWindowState(windowState() | Qt::WindowMaximized);
@@ -1050,32 +1107,22 @@ void MainWindow::saveImage(const Fm::FilePath & filePath) {
 }
 
 void MainWindow::on_actionRotateClockwise_triggered() {
-  if(!image_.isNull()) {
+  if(!ui.view->image().isNull()) {
     ui.view->rotateImage(true);
-    image_ = ui.view->image();
     setModified(true);
   }
 }
 
 void MainWindow::on_actionRotateCounterclockwise_triggered() {
-  if(!image_.isNull()) {
+  if(!ui.view->image().isNull()) {
     ui.view->rotateImage(false);
-    image_ = ui.view->image();
     setModified(true);
   }
 }
 
 void MainWindow::on_actionCopy_triggered() {
   QClipboard *clipboard = QApplication::clipboard();
-  QImage copiedImage = image_;
-  // FIXME: should we copy the currently scaled result instead of the original image?
-  /*
-  double factor = ui.view->scaleFactor();
-  if(factor == 1.0)
-    copiedImage = image_;
-  else
-    copiedImage = image_.scaled();
-  */
+  QImage copiedImage = ui.view->image();
   clipboard->setImage(copiedImage);
 }
 
@@ -1139,31 +1186,28 @@ void MainWindow::on_actionUpload_triggered()
 }
 
 void MainWindow::on_actionFlipVertical_triggered() {
-  if(!image_.isNull()) {
+  if(!ui.view->image().isNull()) {
     ui.view->flipImage(false);
-    image_ = ui.view->image();
     setModified(true);
   }
 }
 
 void MainWindow::on_actionFlipHorizontal_triggered() {
-  if(!image_.isNull()) {
+  if(!ui.view->image().isNull()) {
     ui.view->flipImage(true);
-    image_ = ui.view->image();
     setModified(true);
   }
 }
 
 void MainWindow::on_actionResize_triggered() {
-  if(image_.isNull()) {
+  if(ui.view->image().isNull()) {
     return;
   }
   ResizeImageDialog *dialog = new ResizeImageDialog(this);
-  dialog->setOriginalSize(image_.size());
+  dialog->setOriginalSize(ui.view->image().size());
   if(dialog->exec() == QDialog::Accepted) {
     QSize newSize = dialog->scaledSize();
     if(ui.view->resizeImage(newSize)) {
-      image_ = ui.view->image();
       setModified(true);
     }
   }
@@ -1172,17 +1216,16 @@ void MainWindow::on_actionResize_triggered() {
 
 void MainWindow::setModified(bool modified) {
   imageModified_ = modified;
-  updateUI(); // should be done even if imageModified_ is not changed (because of transformations)
+  // This should be done even if imageModified_ is not changed (because of transformations):
+  updateUI(ui.statusBar->hasPermanentText());
 }
 
 void MainWindow::applySettings() {
   Application* app = static_cast<Application*>(qApp);
   Settings& settings = app->settings();
-  if(isFullScreen())
-    ui.view->setBackgroundBrush(QBrush(settings.fullScreenBgColor()));
-  else
-    ui.view->setBackgroundBrush(QBrush(settings.bgColor()));
-  ui.view->updateOutline();
+  ui.view->setViewBackground(isFullScreen() ? QBrush(settings.fullScreenBgColor())
+                                            : QBrush(settings.bgColor()),
+                             ui.actionSolidBg->isChecked());
   ui.view->setSmoothOnZoom(settings.smoothOnZoom());
   ui.menuRecently_Opened_Files->setMaxItems(settings.maxRecentFiles());
 
@@ -1256,14 +1299,14 @@ void MainWindow::setShortcuts(bool update) {
 void MainWindow::on_actionPrint_triggered() {
   // QPrinter printer(QPrinter::HighResolution);
   QPrinter printer;
-  QPrintDialog dlg(&printer);
+  QPrintDialog dlg(&printer, this);
   if(dlg.exec() == QDialog::Accepted) {
     QPainter painter;
     painter.begin(&printer);
 
     // fit the target rectangle into the viewport if needed and center it
     const QRectF viewportRect = painter.viewport();
-    QRectF targetRect = image_.rect();
+    QRectF targetRect = ui.view->image().rect();
     if(viewportRect.width() < targetRect.width()) {
       targetRect.setSize(QSize(viewportRect.width(), targetRect.height() * (viewportRect.width() / targetRect.width())));
     }
@@ -1274,19 +1317,19 @@ void MainWindow::on_actionPrint_triggered() {
 
     // set the viewport and window of the painter and paint the image
     painter.setViewport(targetRect.toRect());
-    painter.setWindow(image_.rect());
-    painter.drawImage(0, 0, image_);
+    painter.setWindow(ui.view->image().rect());
+    painter.drawImage(0, 0, ui.view->image());
 
     painter.end();
 
     // FIXME: The following code divides the image into columns and could be used later as an option.
     /*QRect pageRect = printer.pageRect();
-    int cols = (image_.width() / pageRect.width()) + (image_.width() % pageRect.width() ? 1 : 0);
-    int rows = (image_.height() / pageRect.height()) + (image_.height() % pageRect.height() ? 1 : 0);
+    int cols = (ui.view->image().width() / pageRect.width()) + (ui.view->image().width() % pageRect.width() ? 1 : 0);
+    int rows = (ui.view->image().height() / pageRect.height()) + (ui.view->image().height() % pageRect.height() ? 1 : 0);
     for(int row = 0; row < rows; ++row) {
       for(int col = 0; col < cols; ++col) {
         QRect srcRect(pageRect.width() * col, pageRect.height() * row, pageRect.width(), pageRect.height());
-        painter.drawImage(QPoint(0, 0), image_, srcRect);
+        painter.drawImage(QPoint(0, 0), ui.view->image(), srcRect);
         if(col + 1 == cols && row + 1 == rows) // this is the last page
           break;
         printer.newPage();
@@ -1326,6 +1369,13 @@ void MainWindow::on_actionShowThumbnails_triggered(bool checked) {
   setShowThumbnails(checked);
 }
 
+void MainWindow::on_actionSolidBg_triggered(bool checked) {
+  Settings& settings = static_cast<Application*>(qApp)->settings();
+  ui.view->setViewBackground(isFullScreen() ? QBrush(settings.fullScreenBgColor())
+                                            : QBrush(settings.bgColor()),
+                             checked);
+}
+
 void MainWindow::on_actionShowOutline_triggered(bool checked) {
   ui.view->showOutline(checked);
 }
@@ -1487,8 +1537,7 @@ void MainWindow::changeEvent(QEvent* event) {
     Settings& settings = static_cast<Application*>(qApp)->settings();
     if(isFullScreen()) { // changed to fullscreen mode
       ui.view->setFrameStyle(QFrame::NoFrame);
-      ui.view->setBackgroundBrush(QBrush(settings.fullScreenBgColor()));
-      ui.view->updateOutline();
+      ui.view->setViewBackground(QBrush(settings.fullScreenBgColor()), ui.actionSolidBg->isChecked());
       ui.toolBar->hide();
       ui.annotationsToolBar->hide();
       ui.statusBar->hide();
@@ -1509,8 +1558,7 @@ void MainWindow::changeEvent(QEvent* event) {
     }
     else { // restore to normal window mode
       ui.view->setFrameStyle(QFrame::StyledPanel|QFrame::Sunken);
-      ui.view->setBackgroundBrush(QBrush(settings.bgColor()));
-      ui.view->updateOutline();
+      ui.view->setViewBackground(QBrush(settings.bgColor()), ui.actionSolidBg->isChecked());
       if(ui.actionMenubar->isChecked()) {
         on_actionMenubar_triggered(true);
       }
