@@ -60,10 +60,6 @@ public:
 
   void openImageFile(const QString& fileName);
 
-  QImage image() const {
-    return image_;
-  }
-
   void pasteImage(QImage newImage);
 
   const Fm::FilePath & currentFile() const {
@@ -126,6 +122,7 @@ private Q_SLOTS:
   void on_actionUpload_triggered();
 
   void on_actionShowThumbnails_triggered(bool checked);
+  void on_actionSolidBg_triggered(bool checked);
   void on_actionShowOutline_triggered(bool checked);
   void on_actionShowExifData_triggered(bool checked);
   void on_actionFullScreen_triggered(bool checked);
@@ -136,6 +133,11 @@ private Q_SLOTS:
   void on_actionFirst_triggered();
   void on_actionLast_triggered();
 
+  void on_actionNextFrame_triggered();
+  void on_actionPreviousFrame_triggered();
+  void on_actionFirstFrame_triggered();
+  void on_actionLastFrame_triggered();
+
   void on_actionZoomIn_triggered();
   void on_actionZoomOut_triggered();
   void on_actionOriginalSize_triggered();
@@ -172,7 +174,7 @@ private Q_SLOTS:
 
 private:
   void onFolderLoaded();
-  void updateUI();
+  void updateUI(bool multiFrame = false);
   void setModified(bool modified);
   QModelIndex indexFromPath(const Fm::FilePath & filePath);
 
@@ -181,7 +183,6 @@ private:
   QMenu* contextMenu_;
   QTimer* slideShowTimer_;
 
-  QImage image_; // the image currently shown
   Fm::FilePath currentFile_; // path to current image file
   // FmFileInfo* currentFileInfo_; // info of the current file, can be NULL
   bool imageModified_; // the current image is modified by rotation, flip, or others and needs to be saved
