@@ -100,7 +100,7 @@ void MruMenu::setMaxItems(int m) {
 
 void MruMenu::onItemTriggered()
 {
-    Q_EMIT itemClicked(qobject_cast<QAction*>(sender())->text());
+    Q_EMIT itemClicked(qobject_cast<QAction*>(sender())->data().toString());
 }
 
 void MruMenu::onClearTriggered()
@@ -119,7 +119,12 @@ void MruMenu::onClearTriggered()
 
 QAction *MruMenu::createAction(const QString &filename)
 {
-    QAction *action = new QAction(filename, this);
+    QFontMetrics metrics(font());
+    int w = 150 * metrics.horizontalAdvance(QLatin1Char(' ')); // for eliding long texts
+    auto name = filename;
+    name.replace(QLatin1Char('&'), QLatin1String("&&")).replace(QLatin1Char('\t'), QLatin1Char(' '));
+    QAction *action = new QAction(metrics.elidedText(name, Qt::ElideMiddle, w), this);
+    action->setData(filename);
     connect(action, &QAction::triggered, this, &MruMenu::onItemTriggered);
     return action;
 }
