@@ -82,6 +82,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent):
   ui.fullScreenBgColor->setColor(settings.fullScreenBgColor());
   ui.maxRecentFiles->setValue(settings.maxRecentFiles());
   ui.slideShowInterval->setValue(settings.slideShowInterval());
+  ui.solidBgBox->setChecked(settings.solidBg());
   ui.oulineBox->setChecked(settings.isOutlineShown());
   ui.menubarBox->setChecked(settings.isMenubarShown());
   ui.toolbarBox->setChecked(settings.isToolbarShown());
@@ -92,7 +93,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent):
 
   oldColorSpace_ = qBound(0, settings.colorSpace(), 5);
   ui.colorSpaceComboBox->setCurrentIndex(oldColorSpace_);
-  connect(ui.colorSpaceComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int index) {
+  connect(ui.colorSpaceComboBox, &QComboBox::currentIndexChanged, this, [](int index) {
     Settings& settings = static_cast<Application*>(qApp)->settings();
     settings.setColorSpace(index);
   });
@@ -155,6 +156,7 @@ void PreferencesDialog::accept() {
   settings.setFullScreenBgColor(ui.fullScreenBgColor->color());
   settings.setMaxRecentFiles(ui.maxRecentFiles->value());
   settings.setSlideShowInterval(ui.slideShowInterval->value());
+  settings.setSolidBg(ui.solidBgBox->isChecked());
   settings.showOutline(ui.oulineBox->isChecked());
   settings.showMenubar(ui.menubarBox->isChecked());
   settings.showToolbar(ui.toolbarBox->isChecked());
